/* LINTLIBRARY */

#pragma ident	"@(#)llib-ltcl7.6.c	1.1	98/11/12 SMI"

#include <tcl.h>

char	*
Tcl_Alloc(unsigned int size)
{
	return (0);
}

void
Tcl_Free(char *ptr)
{
}

char	*
Tcl_Realloc(char *ptr, unsigned int size)
{
	return (0);
}

#if	0
int
Tcl_DumpActiveMemory(char *fileName)
{
	return (0);
}
#endif	/* 0 */

#if	0
void
Tcl_ValidateAllMemory(char *file, int line)
{
}
#endif	/* 0 */

int
Tcl_CreatePipeline(Tcl_Interp *interp, int argc, char **argv,
    int **pidArrayPtr, int *inPipePtr, int *outPipePtr, int *errFilePtr)
{
	return (0);
}


void
Tcl_AddErrorInfo(Tcl_Interp *interp, char *message)
{
}

void
Tcl_AllowExceptions(Tcl_Interp *interp)
{
}

void
Tcl_AppendElement(Tcl_Interp *interp, char *string)
{
}

void
/* CSTYLED */
Tcl_AppendResult TCL_VARARGS(Tcl_Interp *, interp)
{
}

int
Tcl_AppInit(Tcl_Interp *interp)
{
	return (0);
}

Tcl_AsyncHandler
Tcl_AsyncCreate(Tcl_AsyncProc *proc, ClientData clientData)
{
	return (0);
}

void
Tcl_AsyncDelete(Tcl_AsyncHandler async)
{
}

int
Tcl_AsyncInvoke(Tcl_Interp *interp, int code)
{
	return (0);
}

void
Tcl_AsyncMark(Tcl_AsyncHandler async)
{
}

int
Tcl_AsyncReady(void)
{
	return (0);
}

void
Tcl_BackgroundError(Tcl_Interp *interp)
{
}

char
Tcl_Backslash(char *src, int *readPtr)
{
	return (0);
}

void
Tcl_CallWhenDeleted(Tcl_Interp *interp, Tcl_InterpDeleteProc *proc,
    ClientData clientData)
{
}

void
Tcl_CancelIdleCall(Tcl_IdleProc *idleProc, ClientData clientData)
{
}

int
Tcl_Close(Tcl_Interp *interp, Tcl_Channel chan)
{
	return (0);
}

int
Tcl_CommandComplete(char *cmd)
{
	return (0);
}

char	*
Tcl_Concat(int argc, char **argv)
{
	return (0);
}

int
Tcl_ConvertElement(char *src, char *dst, int flags)
{
	return (0);
}

int
Tcl_CreateAlias(Tcl_Interp *slave, char *slaveCmd, Tcl_Interp *target,
    char *targetCmd, int argc, char **argv)
{
	return (0);
}

Tcl_Channel
Tcl_CreateChannel(Tcl_ChannelType *typePtr, char *chanName,
    ClientData instanceData, int mask)
{
	return (0);
}

void
Tcl_CreateChannelHandler(Tcl_Channel chan, int mask,
    Tcl_ChannelProc *proc, ClientData clientData)
{
}

void
Tcl_CreateCloseHandler(Tcl_Channel chan, Tcl_CloseProc *proc,
    ClientData clientData)
{
}

Tcl_Command
Tcl_CreateCommand(Tcl_Interp *interp, char *cmdName,
    Tcl_CmdProc *proc, ClientData clientData, Tcl_CmdDeleteProc *deleteProc)
{
	return (0);
}

void
Tcl_CreateEventSource(Tcl_EventSetupProc *setupProc,
    Tcl_EventCheckProc *checkProc, ClientData clientData)
{
}

void
Tcl_CreateExitHandler(Tcl_ExitProc *proc, ClientData clientData)
{
}

void
Tcl_CreateFileHandler(Tcl_File file, int mask, Tcl_FileProc *proc,
    ClientData clientData)
{
}

Tcl_Interp	*
Tcl_CreateInterp(void)
{
	return (0);
}

void
Tcl_CreateMathFunc(Tcl_Interp *interp, char *name, int numArgs,
    Tcl_ValueType *argTypes, Tcl_MathProc *proc, ClientData clientData)
{
}

void
Tcl_CreateModalTimeout(int milliseconds, Tcl_TimerProc *proc,
    ClientData clientData)
{
}

Tcl_Interp	*
Tcl_CreateSlave(Tcl_Interp *interp, char *slaveName,
    int isSafe)
{
	return (0);
}

Tcl_TimerToken
Tcl_CreateTimerHandler(int milliseconds, Tcl_TimerProc *proc,
    ClientData clientData)
{
	return (0);
}

Tcl_Trace
Tcl_CreateTrace(Tcl_Interp *interp, int level,
    Tcl_CmdTraceProc *proc, ClientData clientData)
{
	return (0);
}

char	*
Tcl_DbCkalloc(unsigned int size, char *file, int line)
{
	return (0);
}

int
Tcl_DbCkfree(char *ptr, char *file, int line)
{
	return (0);
}

char	*
Tcl_DbCkrealloc(char *ptr, unsigned int size, char *file, int line)
{
	return (0);
}

void
Tcl_DeleteAssocData(Tcl_Interp *interp, char *name)
{
}

int
Tcl_DeleteCommand(Tcl_Interp *interp, char *cmdName)
{
	return (0);
}

void
Tcl_DeleteChannelHandler(Tcl_Channel chan, Tcl_ChannelProc *proc,
    ClientData clientData)
{
}

void
Tcl_DeleteCloseHandler(Tcl_Channel chan, Tcl_CloseProc *proc,
    ClientData clientData)
{
}

void
Tcl_DeleteEventSource(Tcl_EventSetupProc *setupProc,
    Tcl_EventCheckProc *checkProc, ClientData clientData)
{
}

void
Tcl_DeleteEvents(Tcl_EventDeleteProc *proc, ClientData clientData)
{
}

void
Tcl_DeleteExitHandler(Tcl_ExitProc *proc, ClientData clientData)
{
}

void
Tcl_DeleteFileHandler(Tcl_File file)
{
}

void
Tcl_DeleteHashEntry(Tcl_HashEntry *entryPtr)
{
}

void
Tcl_DeleteHashTable(Tcl_HashTable *tablePtr)
{
}

void
Tcl_DeleteInterp(Tcl_Interp *interp)
{
}

void
Tcl_DeleteModalTimeout(Tcl_TimerProc *proc, ClientData clientData)
{
}

void
Tcl_DeleteTimerHandler(Tcl_TimerToken token)
{
}

void
Tcl_DeleteTrace(Tcl_Interp *interp, Tcl_Trace trace)
{
}

void
Tcl_DetachPids(int numPids, int *pidPtr)
{
}

void
Tcl_DontCallWhenDeleted(Tcl_Interp *interp, Tcl_InterpDeleteProc *proc,
    ClientData clientData)
{
}

int
Tcl_DoOneEvent(int flags)
{
	return (0);
}

void
Tcl_DoWhenIdle(Tcl_IdleProc *proc, ClientData clientData)
{
}

char	*
Tcl_DStringAppend(Tcl_DString *dsPtr, char *string, int length)
{
	return (0);
}

char	*
Tcl_DStringAppendElement(Tcl_DString *dsPtr, char *string)
{
	return (0);
}

void
Tcl_DStringEndSublist(Tcl_DString *dsPtr)
{
}

void
Tcl_DStringFree(Tcl_DString *dsPtr)
{
}

void
Tcl_DStringGetResult(Tcl_Interp *interp, Tcl_DString *dsPtr)
{
}

void
Tcl_DStringInit(Tcl_DString *dsPtr)
{
}

void
Tcl_DStringResult(Tcl_Interp *interp, Tcl_DString *dsPtr)
{
}

void
Tcl_DStringSetLength(Tcl_DString *dsPtr, int length)
{
}

void
Tcl_DStringStartSublist(Tcl_DString *dsPtr)
{
}

int
Tcl_Eof(Tcl_Channel chan)
{
	return (0);
}

char	*
Tcl_ErrnoId(void)
{
	return (0);
}

char	*
Tcl_ErrnoMsg(int err)
{
	return (0);
}

int
Tcl_Eval(Tcl_Interp *interp, char *cmd)
{
	return (0);
}

int
Tcl_EvalFile(Tcl_Interp *interp, char *fileName)
{
	return (0);
}

void
Tcl_EventuallyFree(ClientData clientData, Tcl_FreeProc *freeProc)
{
}

void
Tcl_Exit(int status)
{
}

int
Tcl_ExprBoolean(Tcl_Interp *interp, char *string, int *ptr)
{
	return (0);
}

int
Tcl_ExprDouble(Tcl_Interp *interp, char *string, double *ptr)
{
	return (0);
}

int
Tcl_ExprLong(Tcl_Interp *interp, char *string, long *ptr)
{
	return (0);
}

int
Tcl_ExprString(Tcl_Interp *interp, char *string)
{
	return (0);
}

int
Tcl_FileReady(Tcl_File file, int mask)
{
	return (0);
}

void
Tcl_FindExecutable(char *argv0)
{
}

Tcl_HashEntry	*
Tcl_FirstHashEntry(Tcl_HashTable *tablePtr, Tcl_HashSearch *searchPtr)
{
	return (0);
}

int
Tcl_Flush(Tcl_Channel chan)
{
	return (0);
}

void
Tcl_FreeFile(Tcl_File file)
{
}

int
Tcl_GetAlias(Tcl_Interp *interp, char *slaveCmd, Tcl_Interp **targetInterpPtr,
    char **targetCmdPtr, int *argcPtr, char ***argvPtr)
{
	return (0);
}

ClientData
Tcl_GetAssocData(Tcl_Interp *interp, char *name, Tcl_InterpDeleteProc **procPtr)
{
	return (0);
}

int
Tcl_GetBoolean(Tcl_Interp *interp, char *string, int *boolPtr)
{
	return (0);
}

Tcl_Channel
Tcl_GetChannel(Tcl_Interp *interp, char *chanName, int *modePtr)
{
	return (0);
}

int
Tcl_GetChannelBufferSize(Tcl_Channel chan)
{
	return (0);
}

Tcl_File
Tcl_GetChannelFile(Tcl_Channel chan, int direction)
{
	return (0);
}

ClientData
Tcl_GetChannelInstanceData(Tcl_Channel chan)
{
	return (0);
}

int
Tcl_GetChannelMode(Tcl_Channel chan)
{
	return (0);
}

char	*
Tcl_GetChannelName(Tcl_Channel chan)
{
	return (0);
}

int
Tcl_GetChannelOption(Tcl_Channel chan, char *optionName, Tcl_DString *dsPtr)
{
	return (0);
}

Tcl_ChannelType	*
Tcl_GetChannelType(Tcl_Channel chan)
{
	return (0);
}

int
Tcl_GetCommandInfo(Tcl_Interp *interp, char *cmdName, Tcl_CmdInfo *infoPtr)
{
	return (0);
}

char	*
Tcl_GetCommandName(Tcl_Interp *interp, Tcl_Command command)
{
	return (0);
}

char	*
Tcl_GetCwd(char *buf, int len)
{
	return (0);
}

int
Tcl_GetDouble(Tcl_Interp *interp, char *string, double *doublePtr)
{
	return (0);
}

int
Tcl_GetErrno(void)
{
	return (0);
}

Tcl_File
Tcl_GetFile(ClientData fileData, int type)
{
	return (0);
}

ClientData
Tcl_GetFileInfo(Tcl_File file, int *typePtr)
{
	return (0);
}

char	*
Tcl_GetHostName(void)
{
	return (0);
}

int
Tcl_GetInt(Tcl_Interp *interp, char *string, int *intPtr)
{
	return (0);
}

int
Tcl_GetInterpPath(Tcl_Interp *askInterp, Tcl_Interp *slaveInterp)
{
	return (0);
}

Tcl_Interp	*
Tcl_GetMaster(Tcl_Interp *interp)
{
	return (0);
}

ClientData
Tcl_GetNotifierData(Tcl_File file, Tcl_FileFreeProc **freeProcPtr)
{
	return (0);
}

int
Tcl_GetOpenFile(Tcl_Interp *interp, char *string, int write, int checkUsage,
    ClientData *filePtr)
{
	return (0);
}

Tcl_PathType
Tcl_GetPathType(char *path)
{
	return (0);
}

int
Tcl_Gets(Tcl_Channel chan, Tcl_DString *dsPtr)
{
	return (0);
}

Tcl_Interp	*
Tcl_GetSlave(Tcl_Interp *interp, char *slaveName)
{
	return (0);
}

Tcl_Channel
Tcl_GetStdChannel(int type)
{
	return (0);
}

char	*
Tcl_GetVar(Tcl_Interp *interp, char *varName, int flags)
{
	return (0);
}

char	*
Tcl_GetVar2(Tcl_Interp *interp, char *part1, char *part2, int flags)
{
	return (0);
}

int
Tcl_GlobalEval(Tcl_Interp *interp, char *command)
{
	return (0);
}

char	*
Tcl_HashStats(Tcl_HashTable *tablePtr)
{
	return (0);
}

int
Tcl_Init(Tcl_Interp *interp)
{
	return (0);
}

void
Tcl_InitHashTable(Tcl_HashTable *tablePtr, int keyType)
{
}

void
Tcl_InitMemory(Tcl_Interp *interp)
{
}

int
Tcl_InputBlocked(Tcl_Channel chan)
{
	return (0);
}

int
Tcl_InputBuffered(Tcl_Channel chan)
{
	return (0);
}

int
Tcl_InterpDeleted(Tcl_Interp *interp)
{
	return (0);
}

int
Tcl_IsSafe(Tcl_Interp *interp)
{
	return (0);
}

char	*
Tcl_JoinPath(int argc, char **argv, Tcl_DString *resultPtr)
{
	return (0);
}

int
Tcl_LinkVar(Tcl_Interp *interp, char *varName, char *addr, int type)
{
	return (0);
}

void
Tcl_Main(int argc, char **argv, Tcl_AppInitProc *appInitProc)
{
}

Tcl_Channel
Tcl_MakeFileChannel(ClientData inFile, ClientData outFile, int mode)
{
	return (0);
}

int
Tcl_MakeSafe(Tcl_Interp *interp)
{
	return (0);
}

Tcl_Channel
Tcl_MakeTcpClientChannel(ClientData tcpSocket)
{
	return (0);
}

char	*
Tcl_Merge(int argc, char **argv)
{
	return (0);
}

Tcl_HashEntry	*
Tcl_NextHashEntry(Tcl_HashSearch *searchPtr)
{
	return (0);
}

Tcl_Channel
Tcl_OpenCommandChannel(Tcl_Interp *interp, int argc, char **argv, int flags)
{
	return (0);
}

Tcl_Channel
Tcl_OpenFileChannel(Tcl_Interp *interp, char *fileName, char *modeString,
    int permissions)
{
	return (0);
}

Tcl_Channel
Tcl_OpenTcpClient(Tcl_Interp *interp, int port, char *address, char *myaddr,
    int myport, int async)
{
	return (0);
}

Tcl_Channel
Tcl_OpenTcpServer(Tcl_Interp *interp, int port, char *host,
    Tcl_TcpAcceptProc *acceptProc, ClientData callbackData)
{
	return (0);
}

char	*
Tcl_ParseVar(Tcl_Interp *interp, char *string, char **termPtr)
{
	return (0);
}

int
Tcl_PkgProvide(Tcl_Interp *interp, char *name, char *version)
{
	return (0);
}

char	*
Tcl_PkgRequire(Tcl_Interp *interp, char *name, char *version, int exact)
{
	return (0);
}

char	*
Tcl_PosixError(Tcl_Interp *interp)
{
	return (0);
}

void
Tcl_Preserve(ClientData data)
{
}

void
Tcl_PrintDouble(Tcl_Interp *interp, double value, char *dst)
{
}

int
Tcl_PutEnv(CONST char *string)
{
	return (0);
}

void
Tcl_QueueEvent(Tcl_Event *evPtr, Tcl_QueuePosition position)
{
}

int
Tcl_Read(Tcl_Channel chan, char *bufPtr, int toRead)
{
	return (0);
}

void
Tcl_ReapDetachedProcs(void)
{
}

int
Tcl_RecordAndEval(Tcl_Interp *interp, char *cmd, int flags)
{
	return (0);
}

Tcl_RegExp
Tcl_RegExpCompile(Tcl_Interp *interp, char *string)
{
	return (0);
}

int
Tcl_RegExpExec(Tcl_Interp *interp, Tcl_RegExp regexp, char *string, char *start)
{
	return (0);
}

int
Tcl_RegExpMatch(Tcl_Interp *interp, char *string, char *pattern)
{
	return (0);
}

void
Tcl_RegExpRange(Tcl_RegExp regexp, int index, char **startPtr, char **endPtr)
{
}

void
Tcl_RegisterChannel(Tcl_Interp *interp, Tcl_Channel chan)
{
}

void
Tcl_Release(ClientData clientData)
{
}

void
Tcl_ResetResult(Tcl_Interp *interp)
{
}

int
Tcl_ScanElement(char *string, int *flagPtr)
{
	return (0);
}

int
Tcl_Seek(Tcl_Channel chan, int offset, int mode)
{
	return (0);
}

void
Tcl_SetAssocData(Tcl_Interp *interp, char *name, Tcl_InterpDeleteProc *proc,
    ClientData clientData)
{
}

void
Tcl_SetChannelBufferSize(Tcl_Channel chan, int sz)
{
}

int
Tcl_SetChannelOption(Tcl_Interp *interp, Tcl_Channel chan, char *optionName,
    char *newValue)
{
	return (0);
}

int
Tcl_SetCommandInfo(Tcl_Interp *interp, char *cmdName, Tcl_CmdInfo *infoPtr)
{
	return (0);
}

void
Tcl_SetErrno(int err)
{
}

void
/* CSTYLED */
Tcl_SetErrorCode TCL_VARARGS(Tcl_Interp *, interp)
{
}

void
Tcl_SetMaxBlockTime(Tcl_Time *timePtr)
{
}

void
Tcl_SetNotifierData(Tcl_File file, Tcl_FileFreeProc *freeProcPtr,
    ClientData data)
{
}

void
Tcl_SetPanicProc(void (*proc) TCL_VARARGS(char *, format))
{
}

int
Tcl_SetRecursionLimit(Tcl_Interp *interp, int depth)
{
	return (0);
}

void
Tcl_SetResult(Tcl_Interp *interp, char *string, Tcl_FreeProc *freeProc)
{
}

void
Tcl_SetStdChannel(Tcl_Channel channel, int type)
{
}

char	*
Tcl_SetVar(Tcl_Interp *interp, char *varName, char *newValue, int flags)
{
	return (0);
}

char	*
Tcl_SetVar2(Tcl_Interp *interp, char *part1, char *part2, char *newValue,
    int flags)
{
	return (0);
}

char	*
Tcl_SignalId(int sig)
{
	return (0);
}

char	*
Tcl_SignalMsg(int sig)
{
	return (0);
}

void
Tcl_Sleep(int ms)
{
}

void
Tcl_SourceRCFile(Tcl_Interp *interp)
{
}

int
Tcl_SplitList(Tcl_Interp *interp, char *list, int *argcPtr, char ***argvPtr)
{
	return (0);
}

void
Tcl_SplitPath(char *path, int *argcPtr, char ***argvPtr)
{
}

void
Tcl_StaticPackage(Tcl_Interp *interp, char *pkgName,
    Tcl_PackageInitProc *initProc, Tcl_PackageInitProc *safeInitProc)
{
}

int
Tcl_StringMatch(char *string, char *pattern)
{
	return (0);
}

int
Tcl_Tell(Tcl_Channel chan)
{
	return (0);
}

int
Tcl_TraceVar(Tcl_Interp *interp, char *varName, int flags,
    Tcl_VarTraceProc *proc, ClientData clientData)
{
	return (0);
}

int
Tcl_TraceVar2(Tcl_Interp *interp, char *part1, char *part2, int flags,
    Tcl_VarTraceProc *proc, ClientData clientData)
{
	return (0);
}

char	*
Tcl_TranslateFileName(Tcl_Interp *interp, char *name, Tcl_DString *bufferPtr)
{
	return (0);
}

void
Tcl_UnlinkVar(Tcl_Interp *interp, char *varName)
{
}

int
Tcl_UnregisterChannel(Tcl_Interp *interp, Tcl_Channel chan)
{
	return (0);
}

int
Tcl_UnsetVar(Tcl_Interp *interp, char *varName, int flags)
{
	return (0);
}

int
Tcl_UnsetVar2(Tcl_Interp *interp, char *part1, char *part2, int flags)
{
	return (0);
}

void
Tcl_UntraceVar(Tcl_Interp *interp, char *varName, int flags,
    Tcl_VarTraceProc *proc, ClientData clientData)
{
}

void
Tcl_UntraceVar2(Tcl_Interp *interp, char *part1, char *part2,
    int flags, Tcl_VarTraceProc *proc, ClientData clientData)
{
}

void
Tcl_UpdateLinkedVar(Tcl_Interp *interp, char *varName)
{
}

int
Tcl_UpVar(Tcl_Interp *interp, char *frameName, char *varName, char *localName,
    int flags)
{
	return (0);
}

int
Tcl_UpVar2(Tcl_Interp *interp, char *frameName, char *part1, char *part2,
    char *localName, int flags)
{
	return (0);
}

int
/* CSTYLED */
Tcl_VarEval TCL_VARARGS(Tcl_Interp *, interp)
{
	return (0);
}

ClientData
Tcl_VarTraceInfo(Tcl_Interp *interp, char *varName, int flags,
    Tcl_VarTraceProc *procPtr, ClientData prevClientData)
{
	return (0);
}

ClientData
Tcl_VarTraceInfo2(Tcl_Interp *interp, char *part1, char *part2, int flags,
    Tcl_VarTraceProc *procPtr, ClientData prevClientData)
{
	return (0);
}

int
Tcl_WaitForEvent(Tcl_Time *timePtr)
{
	return (0);
}

int
Tcl_WaitPid(int pid, int *statPtr, int options)
{
	return (0);
}

void
Tcl_WatchFile(Tcl_File file, int mask)
{
}

int
Tcl_Write(Tcl_Channel chan, char *s, int slen)
{
	return (0);
}
